# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envelope.proto

require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("envelope.proto", :syntax => :proto3) do
    add_message "io.intoto.Envelope" do
      optional :payload, :bytes, 1
      optional :payloadType, :string, 2
      repeated :signatures, :message, 3, "io.intoto.Signature"
    end
    add_message "io.intoto.Signature" do
      optional :sig, :bytes, 1
      optional :keyid, :string, 2
    end
  end
end

module Sigstore
  module DSSE
    Envelope = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("io.intoto.Envelope").msgclass
    Signature = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("io.intoto.Signature").msgclass
  end
end
