// https://github.com/cloudevents/spec/blob/v1.0.2/cloudevents/formats/cloudevents.proto

// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * CloudEvent Protobuf Format
 *
 * - Required context attributes are explicity represented.
 * - Optional and Extension context attributes are carried in a map structure.
 * - Data may be represented as binary, text, or protobuf messages.
 */

 syntax = "proto3";

 package dev.sigstore.events.v1;
  
 import "google/protobuf/any.proto";
 import "google/protobuf/timestamp.proto";
 
 option go_package = "github.com/sigstore/protobuf-specs/gen/pb-go/events/v1";
 option java_package = "dev.sigstore.proto.events.v1";
 option java_multiple_files = true;
 
 message CloudEvent {
 
   // -- CloudEvent Context Attributes
 
   // Required Attributes
   string id = 1;
   string source = 2; // URI-reference
   string spec_version = 3;
   string type = 4;
 
   // Optional & Extension Attributes
   map<string, CloudEventAttributeValue> attributes = 5;
 
   // -- CloudEvent Data (Bytes, Text, or Proto)
   oneof data {
     bytes binary_data = 6;
     string text_data = 7;
     google.protobuf.Any proto_data = 8;
   }
 
   /**
    * The CloudEvent specification defines
    * seven attribute value types...
    */
 
   message CloudEventAttributeValue {
 
     oneof attr {
       bool ce_boolean = 1;
       int32 ce_integer = 2;
       string ce_string = 3;
       bytes ce_bytes = 4;
       string ce_uri = 5;
       string ce_uri_ref = 6;
       google.protobuf.Timestamp ce_timestamp = 7;
     }
   }
 }
 
 /**
  * CloudEvent Protobuf Batch Format
  *
  */
 
 message CloudEventBatch {
   repeated CloudEvent events = 1;
 }
 