# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sigstore_bundle.proto

require 'google/protobuf'

require 'google/api/field_behavior_pb'
require 'envelope_pb'
require 'sigstore_common_pb'
require 'sigstore_rekor_pb'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("sigstore_bundle.proto", :syntax => :proto3) do
    add_message "dev.sigstore.bundle.v1.TimestampVerificationData" do
      repeated :rfc3161_timestamps, :message, 1, "dev.sigstore.common.v1.RFC3161SignedTimestamp"
    end
    add_message "dev.sigstore.bundle.v1.VerificationMaterial" do
      repeated :tlog_entries, :message, 3, "dev.sigstore.rekor.v1.TransparencyLogEntry"
      optional :timestamp_verification_data, :message, 4, "dev.sigstore.bundle.v1.TimestampVerificationData"
      oneof :content do
        optional :public_key, :message, 1, "dev.sigstore.common.v1.PublicKeyIdentifier"
        optional :x509_certificate_chain, :message, 2, "dev.sigstore.common.v1.X509CertificateChain"
      end
    end
    add_message "dev.sigstore.bundle.v1.Bundle" do
      optional :media_type, :string, 1
      optional :verification_material, :message, 2, "dev.sigstore.bundle.v1.VerificationMaterial"
      oneof :content do
        optional :message_signature, :message, 3, "dev.sigstore.common.v1.MessageSignature"
        optional :dsse_envelope, :message, 4, "io.intoto.Envelope"
      end
    end
  end
end

module Sigstore
  module Bundle
    module V1
      TimestampVerificationData = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.bundle.v1.TimestampVerificationData").msgclass
      VerificationMaterial = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.bundle.v1.VerificationMaterial").msgclass
      Bundle = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.bundle.v1.Bundle").msgclass
    end
  end
end
