# Generated by the protocol buffer compiler.  DO NOT EDIT!
# sources: google/api/field_behavior.proto
# plugin: python-betterproto
from dataclasses import dataclass

import betterproto


class FieldBehavior(betterproto.Enum):
    """
    An indicator of the behavior of a given field (for example, that a field is
    required in requests, or given as output but ignored as input). This **does
    not** change the behavior in protocol buffers itself; it only denotes the
    behavior and may affect how API tooling handles the field. Note: This enum
    **may** receive new values in the future.
    """

    FIELD_BEHAVIOR_UNSPECIFIED = 0
    """Conventional default for enums. Do not use this."""

    OPTIONAL = 1
    """
    Specifically denotes a field as optional. While all fields in protocol
    buffers are optional, this may be specified for emphasis if appropriate.
    """

    REQUIRED = 2
    """
    Denotes a field as required. This indicates that the field **must** be
    provided as part of the request, and failure to do so will cause an error
    (usually `INVALID_ARGUMENT`).
    """

    OUTPUT_ONLY = 3
    """
    Denotes a field as output only. This indicates that the field is provided
    in responses, but including the field in a request does nothing (the server
    *must* ignore it and *must not* throw an error as a result of the field's
    presence).
    """

    INPUT_ONLY = 4
    """
    Denotes a field as input only. This indicates that the field is provided in
    requests, and the corresponding field is not included in output.
    """

    IMMUTABLE = 5
    """
    Denotes a field as immutable. This indicates that the field may be set once
    in a request to create a resource, but may not be changed thereafter.
    """

    UNORDERED_LIST = 6
    """
    Denotes that a (repeated) field is an unordered list. This indicates that
    the service may provide the elements of the list in any arbitrary order,
    rather than the order the user originally provided. Additionally, the
    list's order may or may not be stable.
    """
