# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sigstore_rekor.proto

require 'google/protobuf'

require 'google/api/field_behavior_pb'
require 'sigstore_common_pb'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("sigstore_rekor.proto", :syntax => :proto3) do
    add_message "dev.sigstore.rekor.v1.KindVersion" do
      optional :kind, :string, 1
      optional :version, :string, 2
    end
    add_message "dev.sigstore.rekor.v1.Checkpoint" do
      optional :envelope, :string, 1
    end
    add_message "dev.sigstore.rekor.v1.InclusionProof" do
      optional :log_index, :int64, 1
      optional :root_hash, :bytes, 2
      optional :tree_size, :int64, 3
      repeated :hashes, :bytes, 4
      optional :checkpoint, :message, 5, "dev.sigstore.rekor.v1.Checkpoint"
    end
    add_message "dev.sigstore.rekor.v1.InclusionPromise" do
      optional :signed_entry_timestamp, :bytes, 1
    end
    add_message "dev.sigstore.rekor.v1.TransparencyLogEntry" do
      optional :log_index, :int64, 1
      optional :log_id, :message, 2, "dev.sigstore.common.v1.LogId"
      optional :kind_version, :message, 3, "dev.sigstore.rekor.v1.KindVersion"
      optional :integrated_time, :int64, 4
      optional :inclusion_promise, :message, 5, "dev.sigstore.rekor.v1.InclusionPromise"
      optional :inclusion_proof, :message, 6, "dev.sigstore.rekor.v1.InclusionProof"
      optional :canonicalized_body, :bytes, 7
    end
  end
end

module Sigstore
  module Rekor
    module V1
      KindVersion = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.rekor.v1.KindVersion").msgclass
      Checkpoint = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.rekor.v1.Checkpoint").msgclass
      InclusionProof = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.rekor.v1.InclusionProof").msgclass
      InclusionPromise = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.rekor.v1.InclusionPromise").msgclass
      TransparencyLogEntry = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.rekor.v1.TransparencyLogEntry").msgclass
    end
  end
end
