# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: events.proto

require 'google/protobuf'

require 'google/protobuf/any_pb'
require 'google/protobuf/timestamp_pb'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("events.proto", :syntax => :proto3) do
    add_message "dev.sigstore.events.v1.CloudEvent" do
      optional :id, :string, 1
      optional :source, :string, 2
      optional :spec_version, :string, 3
      optional :type, :string, 4
      map :attributes, :string, :message, 5, "dev.sigstore.events.v1.CloudEvent.CloudEventAttributeValue"
      oneof :data do
        optional :binary_data, :bytes, 6
        optional :text_data, :string, 7
        optional :proto_data, :message, 8, "google.protobuf.Any"
      end
    end
    add_message "dev.sigstore.events.v1.CloudEvent.CloudEventAttributeValue" do
      oneof :attr do
        optional :ce_boolean, :bool, 1
        optional :ce_integer, :int32, 2
        optional :ce_string, :string, 3
        optional :ce_bytes, :bytes, 4
        optional :ce_uri, :string, 5
        optional :ce_uri_ref, :string, 6
        optional :ce_timestamp, :message, 7, "google.protobuf.Timestamp"
      end
    end
    add_message "dev.sigstore.events.v1.CloudEventBatch" do
      repeated :events, :message, 1, "dev.sigstore.events.v1.CloudEvent"
    end
  end
end

module Dev
  module Sigstore
    module Events
      module V1
        CloudEvent = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.events.v1.CloudEvent").msgclass
        CloudEvent::CloudEventAttributeValue = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.events.v1.CloudEvent.CloudEventAttributeValue").msgclass
        CloudEventBatch = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.events.v1.CloudEventBatch").msgclass
      end
    end
  end
end
