# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sigstore_trustroot.proto

require 'google/protobuf'

require 'sigstore_common_pb'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("sigstore_trustroot.proto", :syntax => :proto3) do
    add_message "dev.sigstore.trustroot.v1.TransparencyLogInstance" do
      optional :base_url, :string, 1
      optional :hash_algorithm, :enum, 2, "dev.sigstore.common.v1.HashAlgorithm"
      optional :public_key, :message, 3, "dev.sigstore.common.v1.PublicKey"
      optional :log_id, :message, 4, "dev.sigstore.common.v1.LogId"
    end
    add_message "dev.sigstore.trustroot.v1.CertificateAuthority" do
      optional :subject, :message, 1, "dev.sigstore.common.v1.DistinguishedName"
      optional :uri, :string, 2
      optional :cert_chain, :message, 3, "dev.sigstore.common.v1.X509CertificateChain"
      optional :valid_for, :message, 4, "dev.sigstore.common.v1.TimeRange"
    end
    add_message "dev.sigstore.trustroot.v1.TrustedRoot" do
      optional :media_type, :string, 1
      repeated :tlogs, :message, 2, "dev.sigstore.trustroot.v1.TransparencyLogInstance"
      repeated :certificate_authorities, :message, 3, "dev.sigstore.trustroot.v1.CertificateAuthority"
      repeated :ctlogs, :message, 4, "dev.sigstore.trustroot.v1.TransparencyLogInstance"
      repeated :timestamp_authorities, :message, 5, "dev.sigstore.trustroot.v1.CertificateAuthority"
    end
  end
end

module Sigstore
  module TrustRoot
    module V1
      TransparencyLogInstance = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.trustroot.v1.TransparencyLogInstance").msgclass
      CertificateAuthority = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.trustroot.v1.CertificateAuthority").msgclass
      TrustedRoot = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("dev.sigstore.trustroot.v1.TrustedRoot").msgclass
    end
  end
end
